==> vue3-form-create-designer-1.0.0.tgz: package/README.md <==
#  FormCreateDesigner--VUE3+ElementUIPlus实现版本
参考[form-create-designer](http://designer.form-create.com/guide/) 源码升级而成的vue3版本，依然支持官方插件方法。
前端UI组件库：[ElementPlus](https://element-plus.gitee.io/zh-CN/) ，
动态表单组件：[formCreate](http://www.form-create.com/v3/guide/)

## npm
```
npm i vue3-form-create-designer
```

## 使用

1.全局注册 ElementPlus，以及ElementIcons 

由于ElementPlus现已不包含图标，所以需要单独安装ElementIcon，以上这两个依赖都全局注册

main.js
```
...
import { createApp } from 'vue'
const app = createApp(App)
import ElementPlus from 'element-plus'
import 'element-plus/dist/index.css'
import * as ElementIcons from '@element-plus/icons'
// 将 element-plus 的图标库注册到全局
for (const key in ElementIcons) {
	app.component(`ElIcon${ElementIcons[key].name}`, ElementIcons[key])
}
app.use(ElementPlus)
...
```

xxx.vue（注意：组件外层[父盒子]需要指定高度或者给组件传固定高度的[height]属性）
```
<template>
	<div class="fc-designer-wrap">
		<form-designer ref="fcDesignerRef" >
			<template #btns>
				<el-button plain @click="consoleLog($refs.fcDesignerRef)">打印JSON</el-button>
				<el-button plain @click="consoleLogOptions($refs.fcDesignerRef)">打印Options</el-button>
			</template>
		</form-designer>
	</div>
</template>

<script>
	import { defineComponent,ref  } from 'vue'
	import formDesigner from '../../components/FormDesigner'

	export default defineComponent({
		name: 'index',
		components: { formDesigner,},
		setup () {
			const consoleLog = (ref) => {
				// 控制台打印JSON
				console.log('rule', ref.getRule())
			}

			const consoleLogOptions = (ref) => {
				// 控制台打印Option
				console.log('option', ref.getOption())
			}

			return {
				consoleLog,
				consoleLogOptions,
			}
		}
	})
</script>

<style scoped>
	.fc-designer-wrap {
		height: 100vh;
	}
</style>
```

## demo 

[在这里](./src/views/form/index.vue)

==> vue3-form-create-designer-1.0.1.tgz: package/README.md <==
#  FormCreateDesigner--VUE3+ElementUIPlus实现版本
参考[form-create-designer](http://designer.form-create.com/guide/) 源码升级而成的vue3版本，依然支持官方插件方法。
前端UI组件库：[elementPlus](https://element-plus.gitee.io/zh-CN/) ，
动态表单组件：[formCreate](http://www.form-create.com/v3/guide/)

## npm
```
npm i vue3-form-create-designer
```

## 使用

1.全局注册 ElementPlus，以及ElementIcons 

由于ElementPlus现已不包含图标，所以需要单独安装ElementIcon，为了方便开发，建议以上这两个依赖都全局注册

main.js
```
...
import { createApp } from 'vue'
const app = createApp(App)
import ElementPlus from 'element-plus'
import 'element-plus/dist/index.css'
import * as ElementIcons from '@element-plus/icons'
// 将 element-plus 的图标库注册到全局
for (const key in ElementIcons) {
	app.component(`ElIcon${ElementIcons[key].name}`, ElementIcons[key])
}
app.use(ElementPlus)
...
```

xxx.vue（注意：组件外层[父盒子]需要指定高度或者给组件传固定高度的[height]属性）
```
<template>
	<div class="fc-designer-wrap">
		<form-designer ref="fcDesignerRef" >
			<template #btns>
				<el-button plain @click="consoleLog($refs.fcDesignerRef)">打印JSON</el-button>
				<el-button plain @click="consoleLogOptions($refs.fcDesignerRef)">打印Options</el-button>
			</template>
		</form-designer>
	</div>
</template>

<script>
	import { defineComponent,ref  } from 'vue'
	import formDesigner from '../../components/FormDesigner'

	export default defineComponent({
		name: 'index',
		components: { formDesigner,},
		setup () {
			const consoleLog = (ref) => {
				// 控制台打印JSON
				console.log('rule', ref.getRule())
			}

			const consoleLogOptions = (ref) => {
				// 控制台打印Option
				console.log('option', ref.getOption())
			}

			return {
				consoleLog,
				consoleLogOptions,
			}
		}
	})
</script>

<style scoped>
	.fc-designer-wrap {
		height: 100vh;
	}
</style>
```

## demo 

[在这里](./src/views/form/index.vue)
